@@ -116,7 +116,7 @@ def finish(http_host: str ,data: Dict) -> Dict:
 
 def post(url: str, data: Dict) -> Dict:
     logger.debug(f"REST[POST] to [{url}] : data=[{json.dumps(data)}], headers=[{get_headers()}")
-    rsp = requests.post(url, headers=get_headers(), data=json.dumps(data))
+    rsp = requests.post(url, headers=get_headers(), data=json.dumps(data) , verify= False)
     if rsp.status_code not in [200, 201]:
         logger.debug(f"post({url}) failed({rsp.status_code})")
         try:
