@@ -153,7 +153,7 @@ def upload_log(run_id: int, team_name: str, exp_name: str, log_step: int, item_d
     return rsp.rsp_result.result == "success"
 
 
-CHUNK_SIZE = 1024 * 1024  # 1MB
+CHUNK_SIZE = 4* 1024 * 1024  # 1MB
 
 
 def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int,
@@ -353,9 +353,16 @@ def login(key: str) -> (bool, str):
             grpc_url = rsp["grpcHost"]
         # grpc stub 생성
         if use_grpc_tls:
-            channel_opt = ()
-            # channel_opt += (('grpc.ssl_target_name_override', 'bokchi.com'),)
-            channel = grpc.secure_channel(grpc_url, grpc.ssl_channel_credentials(), channel_opt)
+            #channel_opt = ()
+            #channel_opt += (('grpc.ssl_target_name_override', 'lgcn.com'),)
+            # with open('lgcns.crt', 'rb') as f:
+            #     creds = grpc.ssl_channel_credentials(f.read())
+
+            #creds = grpc.ssl_channel_credentials()
+            #grpc_channel_args = (('grpc.ssl_target_name_override', 'bokchi.com'),)
+
+            creds = grpc.ssl_channel_credentials()
+            channel = grpc.secure_channel(target =grpc_url, credentials=creds)#, options=grpc_channel_args)
         else:
             channel = grpc.insecure_channel(grpc_url)
         stub = ResourceStub(channel)
